import { describe, it, expect } from "vitest";
import {
  example,
  BOILERPLATE_OPTIONS,
  createDetails,
} from "../src/constants.js";

describe("constants", () => {
  it("example should be generated and include no build or connector code", () => {
    const result = example({ boilerplate: [] });

    expect(result).toContain(
      'import { NetlifyExtension } from "@netlify/sdk";',
    );
    expect(result).toContain("const extension = new NetlifyExtension();");
    expect(result).toContain("export { extension };");
    expect(result).not.toContain("addBuildEventHandler");
    expect(result).not.toContain("addConnector");
  });

  it("example should be generated and include build code", () => {
    const result = example({ boilerplate: [BOILERPLATE_OPTIONS.build] });

    expect(result).toContain(
      'import { NetlifyExtension } from "@netlify/sdk";',
    );
    expect(result).toContain("const extension = new NetlifyExtension();");
    expect(result).toContain("export { extension };");
    expect(result).toContain("addBuildEventHandler");
    expect(result).not.toContain("addConnector");
  });

  it("example should be generated and include connector code", () => {
    const result = example({
      boilerplate: [BOILERPLATE_OPTIONS.connector],
      connectorSupports: { visualEditor: true, connect: true },
    });

    expect(result).toContain(
      'import { NetlifyExtension } from "@netlify/sdk";',
    );
    expect(result).toContain("const extension = new NetlifyExtension();");
    expect(result).toContain("export { extension };");
    expect(result).not.toContain("addBuildEventHandler");
    expect(result).toContain("addConnector");
    expect(result).toContain("supports: ");
  });

  it("example should be generated and include build and connector code", () => {
    const result = example({
      boilerplate: [BOILERPLATE_OPTIONS.build, BOILERPLATE_OPTIONS.connector],
    });

    expect(result).toContain(
      'import { NetlifyExtension } from "@netlify/sdk";',
    );
    expect(result).toContain("const extension = new NetlifyExtension();");
    expect(result).toContain("export { extension };");
    expect(result).toContain("addBuildEventHandler");
    expect(result).toContain("addConnector");
  });

  it("details file should be generated", () => {
    const extensionName = "Test Extension";
    const result = createDetails(extensionName);
    expect(result).toContain(
      `View and install the ${extensionName} extension.`,
    );
  });
});
